==> 0.0.1.tar.gz: lib/gen_server.dart <==
library gen_server;

import 'dart:io';
import 'dart:async';
import 'dart:core';
import 'dart:convert';
import 'dart:typed_data';

import 'package:uuid/uuid.dart';

import './gen_socket.dart';
import './data_utils.dart';
import './op_codes.dart' as OpCodes;

class GenServer {

  late ServerSocket server;
  late Function(GenSocket gen_socket, String data) onMessageHandler = (GenSocket gen_socket, String data) {};
  late Function(GenSocket gen_socket) onConnectHandler = (GenSocket gen_socket) {};
  late Function(GenSocket gen_socket) onCloseHandler = (GenSocket gen_socket) {};

  String _host = '127.0.0.1';
  int _port = 8080;
  var uuid = Uuid();
  Map<String?, GenSocket?> socketMap = {};

  GenServer({String host = '0.0.0.0', int port = 8080}) {
    this._host = host;
    this._port = port;
  }

  log(String msg) {
    print('[GenServer] $msg');
  }

  onMessage(Function(GenSocket gen_socket, String data) onMessageHandler) {
    this.onMessageHandler = onMessageHandler;
  }

  onConnect(Function(GenSocket gen_socket) onConnectHandler) {
    this.onConnectHandler = onConnectHandler;
  }

  onClose(Function(GenSocket gen_socket) onCloseHandler) {
    this.onCloseHandler = onCloseHandler;
  }

  Future<void> start() async {
    this.server = await ServerSocket.bind(_host, _port);
    server.listen((Socket socket) {
      onNewConnection(GenSocket(socket: socket, id: uuid.v4()));
    });
  }

  putSocket(GenSocket gen_socket) {
    log('Put socket to map. ${gen_socket.id}');
    socketMap[gen_socket.id] = gen_socket;
  }

  delSocket(GenSocket gen_socket) {
    log('Delete socket from map. ${gen_socket.id}');
    socketMap.remove(gen_socket.id);
  }

  Future<void> onNewConnection(GenSocket gen_socket) async {
    await gen_socket.initialize();
    log('Connection from ${gen_socket.remoteAddress}');
    gen_socket.onMessage(this.onMessageHandler);
    gen_socket.onBeforeHandshake(() async {
      await gen_socket.sendHandshakeInfo();
    });
    gen_socket.onConnect(() {
      putSocket(gen_socket);
      log("Connect");
      gen_socket.messages.forEach((message) {
        log(message);
      });
      onConnectHandler(gen_socket);
    });
    gen_socket.onClose(() {
      delSocket(gen_socket);
      log('Close');
      onCloseHandler(gen_socket);
    });
    gen_socket.start();
  }

  /**/
  Future<void> broadcast(String message) async {
    print('broadcast---- $message');
    print(socketMap.length);
    print(socketMap);
    socketMap.forEach((id, gen_socket) {
      // print(key);
      // print(value);
      gen_socket?.sendMessage(message);
    });
  }

  Future<void> sendMessageTo(String? id, String message) async {

  }

  void kickSocketById(String? id) {
    if(socketMap.containsKey(id)) {
      var gen_socket = socketMap[id];
      gen_socket?.disconnect();
    }
  }

  void forEachSocket(callback) {
    socketMap.forEach(callback);
  }

}

==> 0.0.2.tar.gz: lib/gen_server.dart <==
library gen_server;

import 'dart:io';
import 'dart:async';
import 'dart:core';
import 'dart:convert';
import 'dart:typed_data';

import 'package:uuid/uuid.dart';

import './gen_socket.dart';
import './data_utils.dart';
import './op_codes.dart' as OpCodes;

class GenServer {

  late ServerSocket server;
  late Function(GenSocket gen_socket, String data) onMessageHandler = (GenSocket gen_socket, String data) {};
  late Function(GenSocket gen_socket) onConnectHandler = (GenSocket gen_socket) {};
  late Function(GenSocket gen_socket) onCloseHandler = (GenSocket gen_socket) {};

  String _host = '127.0.0.1';
  int _port = 8080;
  var uuid = Uuid();
  Map<String?, GenSocket?> socketMap = {};

  GenServer({String host = '0.0.0.0', int port = 8080}) {
    this._host = host;
    this._port = port;
  }

  void log(String msg) {
    print('[GenServer] $msg');
  }

  void onMessage(Function(GenSocket gen_socket, String data) onMessageHandler) {
    this.onMessageHandler = onMessageHandler;
  }

  void onConnect(Function(GenSocket gen_socket) onConnectHandler) {
    this.onConnectHandler = onConnectHandler;
  }

  void onClose(Function(GenSocket gen_socket) onCloseHandler) {
    this.onCloseHandler = onCloseHandler;
  }

  Future<void> start() async {
    this.server = await ServerSocket.bind(_host, _port);
    server.listen((Socket socket) {
      onNewConnection(GenSocket(socket: socket, id: uuid.v4()));
    });
  }

  void putSocket(GenSocket gen_socket) {
    log('Put socket to map. ${gen_socket.id}');
    socketMap[gen_socket.id] = gen_socket;
  }

  void delSocket(GenSocket gen_socket) {
    log('Delete socket from map. ${gen_socket.id}');
    socketMap.remove(gen_socket.id);
  }

  Future<void> onNewConnection(GenSocket gen_socket) async {
    await gen_socket.initialize();
    log('Connection from ${gen_socket.remoteAddress}');
    gen_socket.onMessage(this.onMessageHandler);
    gen_socket.onBeforeHandshake(() async {
      await gen_socket.sendHandshakeInfo();
    });
    gen_socket.onConnect(() {
      log("Connect");
      putSocket(gen_socket);
      // gen_socket.messages.forEach((message) {
      //   log(message);
      // });
      onConnectHandler(gen_socket);
    });
    gen_socket.onClose(() {
      log('Close');
      delSocket(gen_socket);
      onCloseHandler(gen_socket);
    });
    gen_socket.start();
  }

  /**/
  Future<void> broadcast(String message) async {
    forEachSocket((id, gen_socket) {
      gen_socket?.sendMessage(message);
    });
  }

  Future<void> sendMessageTo(String? id, String message) async {
    if(socketMap.containsKey(id)) {
      var gen_socket = socketMap[id];
      gen_socket?.sendMessage(message);
    }
  }

  void kickSocketById(String? id) {
    if(socketMap.containsKey(id)) {
      var gen_socket = socketMap[id];
      gen_socket?.disconnect();
    }
  }

  void forEachSocket(callback) {
    socketMap.forEach(callback);
  }

}
